@@ -3,7 +3,7 @@ package Date::RangeParser::EN;
 our $AUTHORITY = 'cpan:GSG';
 # ABSTRACT: Parse plain English date/time range strings
 use version;
-our $VERSION = 'v1.0.0'; # VERSION
+our $VERSION = 'v1.0.1'; # VERSION
 
 use strict;
 use warnings;
@@ -55,7 +55,7 @@ my %ordinal = (
     qr/\bseventh\b/         => "7th",  qr/\beighth\b/           => "8th",
     qr/\bninth\b/           => "9th",  qr/\btenth\b/            => "10th",
     qr/\beleventh\b/        => "11th", qr/\btwelfth\b/          => "12th",
-    qr/\bthirteenths\b/     => "13th", qr/\bfourteenth\b/       => "14th",
+    qr/\bthirteenth\b/      => "13th", qr/\bfourteenth\b/       => "14th",
     qr/\bfifteenth\b/       => "15th", qr/\bsixteenth\b/        => "16th",
     qr/\bseventeenth\b/     => "17th", qr/\beighteenth\b/       => "18th",
     qr/\bnineteenth\b/      => "19th", qr/\btwentieth\b/        => "20th",
@@ -187,6 +187,7 @@ sub new
 #pod   MONTH : a month name: January, Feburary, March, April, May, June, July August, 
 #pod           September, October, November, or Decmeber or any 3-letter abbreviation
 #pod   YEAR : a 4-digit year (2-digits will not work)
+#pod   TIMES: January 1st, 2000 at 10:00am through January 1st, 2000 at 2:00pm
 #pod   RANGE : any date range that can be parsed by parse_range
 #pod   ELEMENT : any element of a date range that can be parsed by parse_range
 #pod
@@ -236,6 +237,8 @@ sub new
 #pod   this coming WEEKDAY               : the WEEKDAY that is in the week after this, midnight to midnight
 #pod   this coming Thursday
 #pod
+#pod   NUMBER Business days ago        : past number of business days relative to now until now
+#pod
 #pod   NUMBER PERIOD hence               : now to a future date relative to now
 #pod   4 months hence
 #pod
@@ -268,6 +271,9 @@ sub new
 #pod   CARDINAL of NUMBER months hence   : the specified day of a following month, midnight to midnight
 #pod   22nd of 6 months hence
 #pod
+#pod   CARDINAL of TIME                  : the specific time of day which can be accompanied by a date
+#pod   10:00am through 12:00pm             defaults to today if no date is given
+#pod
 #pod   MONTH                             : the named month of the current year, 1st to last day
 #pod   August
 #pod
@@ -298,6 +304,9 @@ sub new
 #pod   RANGE-RANGE                       : the very start of the first range to the very end of the second
 #pod   10/10-10/20                         (ranges must not contain hyphens, "-")
 #pod
+#pod   American style dates              : Month / Day / Year
+#pod   6/15/2000
+#pod
 #pod   before ELEMENT                    : all dates before the very start of the date specified in the ELEMENT
 #pod        < ELEMENT
 #pod   before today
@@ -1166,7 +1175,7 @@ Date::RangeParser::EN - Parse plain English date/time range strings
 
 =head1 VERSION
 
-version v1.0.0
+version v1.0.1
 
 =head1 SYNOPSIS
 
@@ -1254,6 +1263,7 @@ More formally, this will parse the following kinds of date strings:
   MONTH : a month name: January, Feburary, March, April, May, June, July August, 
           September, October, November, or Decmeber or any 3-letter abbreviation
   YEAR : a 4-digit year (2-digits will not work)
+  TIMES: January 1st, 2000 at 10:00am through January 1st, 2000 at 2:00pm
   RANGE : any date range that can be parsed by parse_range
   ELEMENT : any element of a date range that can be parsed by parse_range
 
@@ -1303,6 +1313,8 @@ More formally, this will parse the following kinds of date strings:
   this coming WEEKDAY               : the WEEKDAY that is in the week after this, midnight to midnight
   this coming Thursday
 
+  NUMBER Business days ago        : past number of business days relative to now until now
+
   NUMBER PERIOD hence               : now to a future date relative to now
   4 months hence
 
@@ -1335,6 +1347,9 @@ More formally, this will parse the following kinds of date strings:
   CARDINAL of NUMBER months hence   : the specified day of a following month, midnight to midnight
   22nd of 6 months hence
 
+  CARDINAL of TIME                  : the specific time of day which can be accompanied by a date
+  10:00am through 12:00pm             defaults to today if no date is given
+
   MONTH                             : the named month of the current year, 1st to last day
   August
 
@@ -1365,6 +1380,9 @@ More formally, this will parse the following kinds of date strings:
   RANGE-RANGE                       : the very start of the first range to the very end of the second
   10/10-10/20                         (ranges must not contain hyphens, "-")
 
+  American style dates              : Month / Day / Year
+  6/15/2000
+
   before ELEMENT                    : all dates before the very start of the date specified in the ELEMENT
        < ELEMENT
   before today
@@ -1496,7 +1514,7 @@ Michael Aquilina <aquilina@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2023 by Grant Street Group.
+This software is Copyright (c) 2012 - 2024 by Grant Street Group.
 
 This is free software, licensed under:
 
